==> jc-1.4.0.tar.gz: soot/baf/internal/AbstractOpTypeBranchInst.h <==
// public abstract class soot.baf.internal.AbstractOpTypeBranchInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class cabcce676e3c10e6 soot_baf_internal_AbstractBranchInst
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 8999e16e077d5b2e soot_baf_internal_AbstractOpTypeBranchInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractBranchInst

#include "soot/baf/internal/AbstractBranchInst.h"

#ifndef _JC_soot_baf_internal_AbstractOpTypeBranchInst_H_
#define _JC_soot_baf_internal_AbstractOpTypeBranchInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitBox$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_refs	_jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_refs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_nonrefs	_jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$refs	_jc_soot_baf_internal_AbstractOpTypeBranchInst$refs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$nonrefs	_jc_soot_baf_internal_AbstractOpTypeBranchInst$nonrefs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object	_jc_soot_baf_internal_AbstractOpTypeBranchInst$object;

typedef const struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$vmethods	_jc_soot_baf_internal_AbstractOpTypeBranchInst$vmethods;
typedef const struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$vtable	_jc_soot_baf_internal_AbstractOpTypeBranchInst$vtable;
typedef const struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$vtype	_jc_soot_baf_internal_AbstractOpTypeBranchInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_AbstractOpTypeBranchInst$method$_init$b9796269265dadfb(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *, struct _jc_soot_Type$object *, struct _jc_object *);

// Virtual methods
extern jint _jc_soot_baf_internal_AbstractOpTypeBranchInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *);
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_AbstractOpTypeBranchInst$method$getOpType$2611df5c7a014636(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *);
extern jint _jc_soot_baf_internal_AbstractOpTypeBranchInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *);
extern void _jc_soot_baf_internal_AbstractOpTypeBranchInst$method$setOpType$96cc62a0f09a0473(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *, struct _jc_soot_Type$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_AbstractOpTypeBranchInst$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *);
extern void _jc_soot_baf_internal_AbstractOpTypeBranchInst$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeBranchInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeBranchInst$method_info$getOpType$2611df5c7a014636;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeBranchInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeBranchInst$method_info$setOpType$96cc62a0f09a0473;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeBranchInst$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeBranchInst$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$vmethods {
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *);
	struct _jc_soot_Type$object	*(*getOpType$2611df5c7a014636)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *);
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *);
	void	(*setOpType$96cc62a0f09a0473)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *, struct _jc_soot_Type$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractBranchInst$vmethods	soot_baf_internal_AbstractBranchInst;
	_jc_soot_baf_internal_AbstractOpTypeBranchInst$vmethods	soot_baf_internal_AbstractOpTypeBranchInst;
};

// Vtype
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_AbstractOpTypeBranchInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_refs {
	struct _jc_soot_Type$object	*opType;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$refs {
    _jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_refs	soot_baf_internal_AbstractOpTypeBranchInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_refs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_nonrefs	soot_baf_internal_AbstractOpTypeBranchInst;
};

// Object instance structure
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object {
	_jc_soot_baf_internal_AbstractOpTypeBranchInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_AbstractOpTypeBranchInst$vtype	*vtype;
	_jc_soot_baf_internal_AbstractOpTypeBranchInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_AbstractOpTypeBranchInst$vtype _jc_soot_baf_internal_AbstractOpTypeBranchInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_AbstractOpTypeBranchInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_AbstractOpTypeBranchInst$class_object;

#endif	/* _JC_soot_baf_internal_AbstractOpTypeBranchInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/AbstractOpTypeBranchInst.h <==
// public abstract class soot.baf.internal.AbstractOpTypeBranchInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class cabcce676e3c10e6 soot_baf_internal_AbstractBranchInst
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 8999e16e077d5b2e soot_baf_internal_AbstractOpTypeBranchInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractBranchInst

#include "soot/baf/internal/AbstractBranchInst.h"

#ifndef _JC_soot_baf_internal_AbstractOpTypeBranchInst_H_
#define _JC_soot_baf_internal_AbstractOpTypeBranchInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitBox$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_refs	_jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_refs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_nonrefs	_jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$refs	_jc_soot_baf_internal_AbstractOpTypeBranchInst$refs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$nonrefs	_jc_soot_baf_internal_AbstractOpTypeBranchInst$nonrefs;
typedef struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object	_jc_soot_baf_internal_AbstractOpTypeBranchInst$object;

typedef const struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$vmethods	_jc_soot_baf_internal_AbstractOpTypeBranchInst$vmethods;
typedef const struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$vtable	_jc_soot_baf_internal_AbstractOpTypeBranchInst$vtable;
typedef const struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$vtype	_jc_soot_baf_internal_AbstractOpTypeBranchInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_AbstractOpTypeBranchInst$method$_init$b9796269265dadfb(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *, struct _jc_soot_Type$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_baf_internal_AbstractOpTypeBranchInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_AbstractOpTypeBranchInst$method$getOpType$2611df5c7a014636(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_AbstractOpTypeBranchInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_AbstractOpTypeBranchInst$method$setOpType$96cc62a0f09a0473(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_AbstractOpTypeBranchInst$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_AbstractOpTypeBranchInst$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeBranchInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeBranchInst$method_info$getOpType$2611df5c7a014636;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeBranchInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeBranchInst$method_info$setOpType$96cc62a0f09a0473;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeBranchInst$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_baf_internal_AbstractOpTypeBranchInst$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$vmethods {
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getOpType$2611df5c7a014636)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *) _JC_JCNI_ATTR;
	void	(*setOpType$96cc62a0f09a0473)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractBranchInst$vmethods	soot_baf_internal_AbstractBranchInst;
	_jc_soot_baf_internal_AbstractOpTypeBranchInst$vmethods	soot_baf_internal_AbstractOpTypeBranchInst;
};

// Vtype
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_AbstractOpTypeBranchInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_refs {
	struct _jc_soot_Type$object	*opType;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$refs {
    _jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_refs	soot_baf_internal_AbstractOpTypeBranchInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_refs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_AbstractOpTypeBranchInst$sub_nonrefs	soot_baf_internal_AbstractOpTypeBranchInst;
};

// Object instance structure
struct _jc_soot_baf_internal_AbstractOpTypeBranchInst$object {
	_jc_soot_baf_internal_AbstractOpTypeBranchInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_AbstractOpTypeBranchInst$vtype	*vtype;
	_jc_soot_baf_internal_AbstractOpTypeBranchInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_AbstractOpTypeBranchInst$vtype _jc_soot_baf_internal_AbstractOpTypeBranchInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_AbstractOpTypeBranchInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_AbstractOpTypeBranchInst$class_object;

#endif	/* _JC_soot_baf_internal_AbstractOpTypeBranchInst_H_ */
